@@ -98,7 +98,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex_suite-2.0"));
+	setCaption(tr("segatex_suite-2.1"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -804,7 +804,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex_suite"),
-		tr("<h2>segatex_suite-2.0</h2>"
+		tr("<h2>segatex_suite-2.1</h2>"
 		"<p>Copyright &copy; 2007"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex_suite is a SELinux tool"
@@ -819,7 +819,8 @@ void MainWindow::howtouse()
 		"<p>You can set selinux enforcing"
 		" and permissive just pushing button."
 		" You can install/update SELinux related"
-		" RPMs.You can audit2allow -m local -a."
+		" RPMs.You can audit2allow -m local -a"
+		" with other options,-l -R -v -e."
 		" You can analize audit log."
 		" You can generate interfaced policy,by "
 		" Analize audit.log-generate policy."
@@ -834,7 +835,6 @@ void MainWindow::howtouse()
 		" that is a success."
 		"<p>Break kernel may take 30 minutes, and"
 		" Refine selpaw takes 10 minutes;)</p>"));
-
 }
 
 
